==> openshift-client-4.13.2-sources.jar: io/fabric8/openshift/client/handlers/ClusterResourceQuotaHandler.java <==

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.ClusterResourceQuotaOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.ClusterResourceQuota;
import io.fabric8.openshift.api.model.ClusterResourceQuotaBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class ClusterResourceQuotaHandler implements ResourceHandler<ClusterResourceQuota, ClusterResourceQuotaBuilder> {

  @Override
  public String getKind() {
    return ClusterResourceQuota.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "quota.openshift.io/v1";
    }

  @Override
  public ClusterResourceQuota create(OkHttpClient client, Config config, String namespace, ClusterResourceQuota item) {
    return new ClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public ClusterResourceQuota replace(OkHttpClient client, Config config, String namespace, ClusterResourceQuota item) {
    return new ClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public ClusterResourceQuota reload(OkHttpClient client, Config config, String namespace, ClusterResourceQuota item) {
    return new ClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public ClusterResourceQuotaBuilder edit(ClusterResourceQuota item) {
    return new ClusterResourceQuotaBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, ClusterResourceQuota item) {
    return new ClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).withPropagationPolicy(propagationPolicy).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ClusterResourceQuota item, Watcher<ClusterResourceQuota> watcher) {
    return new ClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ClusterResourceQuota item, String resourceVersion, Watcher<ClusterResourceQuota> watcher) {
    return new ClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ClusterResourceQuota item, ListOptions options, Watcher<ClusterResourceQuota> watcher) {
  return new ClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public ClusterResourceQuota waitUntilReady(OkHttpClient client, Config config, String namespace, ClusterResourceQuota item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new ClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public ClusterResourceQuota waitUntilCondition(OkHttpClient client, Config config, String namespace, ClusterResourceQuota item, Predicate<ClusterResourceQuota> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new ClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> openshift-client-5.2.0-sources.jar: io/fabric8/openshift/client/handlers/ClusterResourceQuotaHandler.java <==

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.ClusterResourceQuotaOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.ClusterResourceQuota;
import io.fabric8.openshift.api.model.ClusterResourceQuotaBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class ClusterResourceQuotaHandler implements ResourceHandler<ClusterResourceQuota, ClusterResourceQuotaBuilder> {

  @Override
  public String getKind() {
    return ClusterResourceQuota.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "quota.openshift.io/v1";
    }

  @Override
  public ClusterResourceQuota create(OkHttpClient client, Config config, String namespace, ClusterResourceQuota item, boolean dryRun) {
    return new ClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).dryRun(dryRun).create();
  }

  @Override
  public ClusterResourceQuota replace(OkHttpClient client, Config config, String namespace, ClusterResourceQuota item, boolean dryRun) {
    return new ClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).dryRun(dryRun).replace(item);
  }

  @Override
  public ClusterResourceQuota reload(OkHttpClient client, Config config, String namespace, ClusterResourceQuota item) {
    return new ClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public ClusterResourceQuotaBuilder edit(ClusterResourceQuota item) {
    return new ClusterResourceQuotaBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, long gracePeriodSeconds, ClusterResourceQuota item, boolean dryRun) {
    return new ClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).dryRun(dryRun).withPropagationPolicy(propagationPolicy).withGracePeriod(gracePeriodSeconds).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ClusterResourceQuota item, Watcher<ClusterResourceQuota> watcher) {
    return new ClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ClusterResourceQuota item, String resourceVersion, Watcher<ClusterResourceQuota> watcher) {
    return new ClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, ClusterResourceQuota item, ListOptions options, Watcher<ClusterResourceQuota> watcher) {
  return new ClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public ClusterResourceQuota waitUntilReady(OkHttpClient client, Config config, String namespace, ClusterResourceQuota item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new ClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public ClusterResourceQuota waitUntilCondition(OkHttpClient client, Config config, String namespace, ClusterResourceQuota item, Predicate<ClusterResourceQuota> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new ClusterResourceQuotaOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}
